@@ -1,25 +1,17 @@
-import os, time, logging
+import os, logging
 from struct import unpack
 import numpy as np
 from . import sfdics, str_byt
 
 n_rel = 8
 
-fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s')
-hnd = logging.StreamHandler()
-hnd.setFormatter(fmt)
-hnd.setLevel(level=logging.INFO)
-logger = logging.getLogger('sfhread')
-logger.addHandler(hnd)
-logger.setLevel(logging.INFO)
-logger.propagate = False
+logger = logging.getLogger('aug_sfutils.sfhread')
 
 
 def read_sfh(byt_str):
     """
     Reads a full shotfile header
     """
-    tbeg = time.time()
 
     sfhead = {}
     sfhead['obj_nam'] = []
@@ -65,9 +57,6 @@ def read_sfh(byt_str):
         if j == n_obj - 1:
             break
 
-    tend = time.time()
-    logger.debug('Time SFHread: %8.4f' %(tend - tbeg))
-
     return sfhead
 
 
