@@ -6,14 +6,7 @@ from . import sfdics, sfhread, sfobj, manage_ed, parse_kwargs, str_byt, libddc
 
 PPGCLOCK = [1e-6, 1e-5, 1e-4, 1e-3]
 
-fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
-hnd = logging.StreamHandler()
-hnd.setFormatter(fmt)
-hnd.setLevel(level=logging.INFO)
-logger = logging.getLogger('sfread')
-logger.addHandler(hnd)
-logger.setLevel(logging.INFO)
-logger.propagate = False
+logger = logging.getLogger('aug_sfutils.sfread')
 
 
 def read_other_sf(*args, **kwargs):
@@ -244,7 +237,7 @@ class SFREAD:
             elif name in self.parsets:
                 self.cache[name] = self.getparset(name)
             else:
-                logger.error('Signal %s not found in diag %s' %(name, self.diag))
+                logger.error('Signal %s:%s not found for shot #%d', self.diag, name, self.shot)
                 return None
         return self.cache[name]
 
