@@ -3,14 +3,7 @@ import ctypes as ct
 import numpy as np
 from . import sfdics, str_byt
 
-fmt = logging.Formatter('%(asctime)s | %(name)s | %(levelname)s: %(message)s', '%Y-%m-%d %H:%M:%S')
-hnd = logging.StreamHandler()
-hnd.setFormatter(fmt)
-hnd.setLevel(level=logging.INFO)
-logger = logging.getLogger('ww')
-logger.addHandler(hnd)
-logger.setLevel(logging.INFO)
-logger.propagate = False
+logger = logging.getLogger('aug_sfutils.ww')
 
 wwlib = '/afs/ipp-garching.mpg.de/aug/ads/lib64/@sys/libddww8.so.8.1'
 if not os.path.isfile(wwlib):
